Colourettu version |version| documentation
==========================================

.. image:: colourettu-logo-4x.png
	:align: center

Colourettu is a small collection of colour functions in Python.
These can be used to determine the (relative) luminosity of a colour
and the contrast between two colours. There is also the palette class
for dealing with a 'list' of colours.

To install colourettu, the easiest way is to use `pip`::

    pip install colourettu

Find what to read more using the Documentation
:doc:`Table of Contents </contents>` (or use the 'next' button).

Note on Spelling
----------------

I have used the Canadian/British spelling of *colour* through this and
the code.

Links
-----

- Code, on GitHub: http://www.github.com/minchinweb/colourettu/
- Report a Bug! https://github.com/minchinweb/colourettu/issues
- Documentation: http://minchin.ca/colourettu/
- Listing on PyPI: https://pypi.python.org/pypi/colourettu

.. image:: https://img.shields.io/pypi/v/colourettu.svg?style=flat
    :target: https://pypi.python.org/pypi/colourettu/

.. image:: https://api.travis-ci.org/MinchinWeb/colourettu.svg?branch=master
    :target: http://travis-ci.org/MinchinWeb/colourettu

.. image:: https://coveralls.io/repos/MinchinWeb/colourettu/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/MinchinWeb/colourettu?branch=master

.. image:: https://img.shields.io/pypi/l/colourettu.svg?style=flat
    :target: https://github.com/MinchinWeb/colourettu/blob/master/LICENSE

License
-------

*Colourettu* is licensed under the MIT license. :doc:`Read full license </license>`.



..  Indices and tables
    ------------------

    * :ref:`genindex`
    * :ref:`modindex`
    * :ref:`search`

